from themoviedb.routes.base import Base
from themoviedb.routes.credit import Credit
from themoviedb.routes.companies import Company
from themoviedb.routes.collections import Collection
from themoviedb.routes.discover import Discover
from themoviedb.routes.episodes import Episode
from themoviedb.routes.find import Find
from themoviedb.routes.genres import Genres
from themoviedb.routes.keywords import Keyword
from themoviedb.routes.movies import Movie, Movies
from themoviedb.routes.people import People, Person
from themoviedb.routes.network import Network
from themoviedb.routes.reviews import Review
from themoviedb.routes.search import Search
from themoviedb.routes.seasons import Season
from themoviedb.routes.trending import Trending
from themoviedb.routes.tv import TV, TVs
from themoviedb.routes.watch_providers import WatchProviders
